summaryrefslogtreecommitdiffstats
path: root/kommander/factory/domtool.h
diff options
context:
space:
mode:
Diffstat (limited to 'kommander/factory/domtool.h')
-rw-r--r--kommander/factory/domtool.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kommander/factory/domtool.h b/kommander/factory/domtool.h
index 034cb98e..30f26b51 100644
--- a/kommander/factory/domtool.h
+++ b/kommander/factory/domtool.h
@@ -1,7 +1,7 @@
/**********************************************************************
** Copyright (C) 2000 Trolltech AS. All rights reserved.
**
** This file is part of Qt Designer.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
@@ -27,7 +27,7 @@
class TQDomElement;
class TQDomDocument;
-class DomTool : public Qt
+class DomTool : public TQt
{
public:
static TQVariant readProperty( const TQDomElement& e, const TQString& name, const TQVariant& defValue );
@@ -1,7 +1,7 @@
** Copyright (C) 2000 Trolltech AS. All rights reserved.
**
-** This file is part of Qt Designer.
+** This file is part of TQt Designer.
**
** This file may be distributed and/or modified under the terms of the